==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privaat",
    "Published" : "Gepubliseer",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Gemiddelde wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Groups" : "Groepe",
    "Group list is empty" : "Groeplys is leeg",
    "Unable to retrieve the group list" : "Kan nie die groeplys ophaal nie",
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Wrong password" : "Verkeerde wagwoord",
    "Saved" : "Bewaar",
    "No user supplied" : "Geen gebruiker verskaf nie",
    "Well done, %s!" : "Welgedaan %s!",
    "Invalid user" : "Ongeldige gebruiker",
    "Invalid mail address" : "Ongeldige posadres",
    "Settings saved" : "Instellings gestoor",
    "Go to %s" : "Gaan na %s",
    "Apps" : "Toeps",
    "Settings" : "Instellings",
    "Personal" : "Persoonlik",
    "Personal info" : "Persoonlike inligting",
    "Create" : "Skep",
    "Delete" : "Skrap",
    "Unlimited" : "Onbeperkte",
    "None" : "Geen",
    "Save changes" : "Bewaar veranderinge",
    "All" : "Alle",
    "Update to {version}" : "Werk by na {version}",
    "Remove" : "Verwyder",
    "Disable" : "Deaktiveer",
    "View in store" : "Bekyk in winkel",
    "Visit website" : "Besoek webwerf",
    "User documentation" : "Gebruikerdokumentasie",
    "Admin documentation" : "Admindokumentasie",
    "Developer documentation" : "Ontwikkelaardokumentasie",
    "Rename" : "Hernoem",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "Done" : "Gereed",
    "Copied!" : "Gekopieer!",
    "Copy" : "Kopieer",
    "Profile" : "Profiel",
    "Enable" : "Aktiveer",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "Cancel" : "Kanselleer",
    "Details" : "Besonderhede",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "Language" : "Taal",
    "Help translate" : "Help met vertaling",
    "Your phone number" : "U foonnommer",
    "Your Twitter handle" : "U Twitter-handvatsel",
    "Your website" : "U webwerf",
    "Add" : "Voeg by",
    "Display name" : "Vertoonnaam",
    "Email" : "E-pos",
    "Group admin for" : "Groepadmin vir",
    "Quota" : "Kwota",
    "Last login" : "Laaste aantekening",
    "Default quota" : "Verstekkwota",
    "Unnamed device" : "Onbenoemde toestel",
    "Your apps" : "U toeps",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "Updates" : "Bywerkings",
    "App bundles" : "Toepbundels",
    "Changelog" : "Veranderingslog",
    "Active users" : "Aktiewe gebruikers",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "Email sent" : "E-pos gestuur",
    "Location" : "Ligging",
    "Profile picture" : "Profielprent",
    "About" : "Oor",
    "Full name" : "Volle naam",
    "Phone number" : "Foonnommer",
    "Twitter" : "Twitter",
    "Website" : "Webwerf",
    "Never" : "Nooit",
    "Administrator documentation" : "Administrateurdokumentasie",
    "Documentation" : "Dokumentasie",
    "Forum" : "Forum",
    "Login" : "Teken aan",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Open dokumentasie",
    "Encryption" : "Enkripsie",
    "Authentication required" : "Verifikasie word vereis",
    "Server address" : "Bedieneradres",
    "Port" : "Poort",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Version" : "Weergawe",
    "Like our Facebook page" : "Hou van ons Facebook-blad",
    "Follow us on Twitter" : "Volg ons op Twitter",
    "Check out our blog" : "Besoek ons woernaal",
    "Subscribe to our newsletter" : "Teken in op ons nuusbrief",
    "All languages" : "Alle tale",
    "Everyone" : "Almal",
    "days" : "dae",
    "Upload new" : "Laai nuwe op",
    "Select from Files" : "Kies uit Lêers",
    "Remove image" : "Verwyder beeld",
    "Choose as profile picture" : "Kies as profielprent",
    "Address" : "Adres",
    "Your postal address" : "U posadres",
    "Link https://…" : "Skakel https://…",
    "Twitter handle @…" : "Twitter-handvatsel @…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/af.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privaat",
    "Published" : "Gepubliseer",
    "Very weak password" : "Baie swak wagwoord",
    "Weak password" : "Swak wagwoord",
    "So-so password" : "Gemiddelde wagwoord",
    "Good password" : "Goeie wagwoord",
    "Strong password" : "Sterk wagwoord",
    "Groups" : "Groepe",
    "Group list is empty" : "Groeplys is leeg",
    "Unable to retrieve the group list" : "Kan nie die groeplys ophaal nie",
    "{actor} changed your password" : "{actor} het u wagwoord verander",
    "You changed your password" : "U het u wagwoord verander",
    "Your password was reset by an administrator" : "U wagwoord is deur ’n administrateur herstel",
    "{actor} changed your email address" : "{actor} het u e-posadres verander",
    "You changed your email address" : "U het u e-posadres verander",
    "Your email address was changed by an administrator" : "U e-posadres is deur ’n administrateur verander",
    "Security" : "Sekuriteit",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "U <strong>wagwoord</strong> of <strong>e-pos</strong> is gewysig",
    "Apps" : "Toeps",
    "Wrong password" : "Verkeerde wagwoord",
    "Saved" : "Bewaar",
    "No user supplied" : "Geen gebruiker verskaf nie",
    "Administrator documentation" : "Administrateurdokumentasie",
    "User documentation" : "Gebruikerdokumentasie",
    "Well done, %s!" : "Welgedaan %s!",
    "Users" : "Gebruikers",
    "Invalid user" : "Ongeldige gebruiker",
    "Invalid mail address" : "Ongeldige posadres",
    "Settings saved" : "Instellings gestoor",
    "Go to %s" : "Gaan na %s",
    "Settings" : "Instellings",
    "Personal" : "Persoonlik",
    "Calendar" : "Kalender",
    "Personal info" : "Persoonlike inligting",
    "Create" : "Skep",
    "Delete" : "Skrap",
    "Unlimited" : "Onbeperkte",
    "None" : "Geen",
    "Save changes" : "Bewaar veranderinge",
    "All" : "Alle",
    "Update to {version}" : "Werk by na {version}",
    "Remove" : "Verwyder",
    "Disable" : "Deaktiveer",
    "View in store" : "Bekyk in winkel",
    "Visit website" : "Besoek webwerf",
    "Admin documentation" : "Admindokumentasie",
    "Developer documentation" : "Ontwikkelaardokumentasie",
    "Rename" : "Hernoem",
    "Device" : "Toestel",
    "App name" : "Toepnaam",
    "Create new app password" : "Skep nuwe toepwagwoord",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "Done" : "Gereed",
    "Copied!" : "Gekopieer!",
    "Copy" : "Kopieer",
    "Profile" : "Profiel",
    "Enable" : "Aktiveer",
    "Current password" : "Huidige wagwoord",
    "New password" : "Nuwe wagwoord",
    "Change password" : "Verander wagwoord",
    "Cancel" : "Kanselleer",
    "Details" : "Besonderhede",
    "Your email address" : "U e-posadres",
    "No email address set" : "Geen e-posadres ingestel",
    "Language" : "Taal",
    "Help translate" : "Help met vertaling",
    "Your phone number" : "U foonnommer",
    "Your Twitter handle" : "U Twitter-handvatsel",
    "Your website" : "U webwerf",
    "Add" : "Voeg by",
    "Display name" : "Vertoonnaam",
    "Email" : "E-pos",
    "Quota" : "Kwota",
    "Group admin for" : "Groepadmin vir",
    "Last login" : "Laaste aantekening",
    "Unnamed device" : "Onbenoemde toestel",
    "Your apps" : "U toeps",
    "Changelog" : "Veranderingslog",
    "Active users" : "Aktiewe gebruikers",
    "Send email to new user" : "Stuur e-pos aan nuwe gebruiker",
    "Email sent" : "E-pos gestuur",
    "Location" : "Ligging",
    "Profile picture" : "Profielprent",
    "About" : "Oor",
    "Full name" : "Volle naam",
    "Phone number" : "Foonnommer",
    "Twitter" : "Twitter",
    "Website" : "Webwerf",
    "Disabled apps" : "Gedeaktiveerde toeps",
    "Updates" : "Bywerkings",
    "App bundles" : "Toepbundels",
    "Never" : "Nooit",
    "Default quota" : "Verstekkwota",
    "Documentation" : "Dokumentasie",
    "Forum" : "Forum",
    "Login" : "Teken aan",
    "Open documentation" : "Open dokumentasie",
    "Encryption" : "Enkripsie",
    "Server address" : "Bedieneradres",
    "Port" : "Poort",
    "Authentication required" : "Verifikasie word vereis",
    "SMTP Password" : "SMTP-wagwoord",
    "Save" : "Stoor",
    "Version" : "Weergawe",
    "Like our Facebook page" : "Hou van ons Facebook-blad",
    "Follow us on Twitter" : "Volg ons op Twitter",
    "Check out our blog" : "Besoek ons woernaal",
    "Subscribe to our newsletter" : "Teken in op ons nuusbrief",
    "png or jpg, max. 20 MB" : "png of jpg, maks. 20 MB",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS"
},
"nplurals=2; plural=(n != 1);");
